#!/usr/bin/python
# -*- coding: utf-8 -*-
###########################################################################
# Eole NG - 2007  
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr 
#  
# Eole-register
#  
# Ce logiciel permet de déterminer la configuration matérielle d'une machine
# afin d'alimenter une base de données de matériel compatible.
#       
###########################################################################
"""Script principal, lance le parsing et la connexion au serveur
"""
from lshw_parser import inst_computer
import os.path
import xmlrpclib
import commands
from xml.etree.ElementTree import fromstring
from config import SERVEREOLE, VERSIONEOLE
import pickle

def initialize():
    """
    Teste avec fonction *ping* si le serveur est disponible, si non quitte
    vérifie :
    - si materiel (empreinte du matériel) existe, 
    - si non le crée et lance le parsing
    
    - si oui, vérifie la chaine contenue en la comparant avec un md5 de lswh.xml
    - si identique (aucun changement matériel) **ne fait rien**
    - si différent (chanchement matériel) **refait le fichier materiel 
      et renvoie la nouvelle conf (parsing de lshw)**
    """
    print "Test de connexion avec le serveur..."
    try:
        server = xmlrpclib.Server(SERVEREOLE)
        ping = server.ping()
        if ping == '1':
            print ' -> Ping du serveur réussi'
    except:
        print ' -> Impossible de contacter le serveur...'
        return
    if os.path.exists('materiel'):
        fichier = open('materiel', 'r')
        old = pickle.load(fichier)
        fichier.close()
        try:
            tree = execute_lshw()
        except:
            print "Problème de serialisation du XML"
            return
        computer = inst_computer(tree)
        resultat = computer.todict()
        if old == resultat:
            print '----Aucun changement matériel détecté'
            print '----Mise à jour des informations de connexion...'
            dico_compt = {}
            dico_compt['id'] = check_id()
            dico_compt['version'] = get_version()
            server.compt(dico_compt)
            return
        else:
            print '----Changement matériel détecté, détection automatique'
            fichier = open('materiel','w')
            pickle.dump(resultat, fichier)
            try:
                tree = execute_lshw()
            except:
                print "Problème de sérialisation du XML"
                return
            computer = inst_computer(tree)
            resultat = computer.todict()
            resultat['id'] = check_id()
            resultat['version'] = get_version()
            try:
                server.recover(resultat)
            except:
                print "Erreur d'enregistrement"
                return
    else:
        print '----Nouvelle installation détectée'
        fichier = open('materiel','w')
        try:
            tree = execute_lshw()
        except:
            print "Problème de sérialisation du XML"
            return
        computer = inst_computer(tree)
        resultat = computer.todict()
        pickle.dump(resultat, fichier)
        resultat['id'] = check_id()
        resultat['version'] = get_version()
        try:
            server.recover(resultat)
        except:
            print "Erreur d'enregistrement"
            return
        print "----Opération terminée avec succès"

def get_version():
    """recuperes le contenu de /eole/version, en enlevant le /n
    """
    try:
        file_eole = open(VERSIONEOLE,'r')
    except IOError : return 'erreur'
    eole_version = file_eole.readline()
    file_eole.close()
    return eole_version.strip()

def get_md5sum():
    """renvoie l'empreinte materielle
    n'est utilise qu'une seule fois pour generer l'empreinte unique
    """
    os.system('lshw -xml > lshw.xml')
    md5_result = commands.getoutput('md5sum lshw.xml')
    md5 = md5_result.split()
    md5_chain = md5[0]
    os.remove('lshw.xml')
    return md5_chain

def check_id():
    """cree un fichier unique identifiant a partir du lshw si non existant,
    sinon lit simplement le contenu et le renvoie
    """
    if not os.path.exists('id'):
        id_unique = get_md5sum()
        fichier = open('id', 'w').write(id_unique)
        return id_unique
    else:
        try:
            fichier = open('id')
            id_unique = fichier.readline()
            return id_unique
        except:
            raise Exception, "Problème de lecture de l'identifiant"

#utilitaire de récupération de la sortie lshw
def execute_lshw():
    """execute la commande lshw et renvoie l'arbre correspondant
    """
    temp = commands.getoutput("lshw -xml 2>/dev/null")
    try:
        tree = fromstring(temp)
    except:
        raise Exception, 'XML malformé'
    return tree

if __name__ == '__main__':
    initialize()
